Crate kcr_bmc_tinkerbell_org

Crate kcr_bmc_tinkerbell_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the bmc.tinkerbell.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

bmc.tinkerbell.org/v1alpha1

  • Job
  • Machine
  • Task

Modules

v1alpha1